@@ -1,8 +1,8 @@
 """Top-level package for yolo-tiling."""
 
-from yolo_tiler.yolo_tiler import YoloTiler, TileConfig
+from yolo_tiler.yolo_tiler import YoloTiler, TileConfig, TileProgress
 
-__version__ = "0.0.3"
+__version__ = "0.0.13"
 __author__ = "Jordan Pierce"
 __email__ = "jordan.pierce@noaa.gov"
 __credits__ = "National Center for Coastal and Ocean Sciences (NCCOS)"
